{% extends "synopticbase.html" %}
{% load i18n %}


{% block title %}
  {% blocktrans with name=object.station.name %}
    Weather conditions at {{ name }}
  {% endblocktrans %}
{% endblock %}


{% block content %}
  {% block breadcrumbs %}
    <ol class="breadcrumb">
      <li><a href="../../">{% blocktrans with name=object.synoptic_group.name %}{{ name }} meteorological report{% endblocktrans %}</a></li>
      {% url 'station_detail' object.station.id as station_page %}
      <li class="active">{% blocktrans with name=object.station.name %}Weather conditions at <a href="{{ station_page }}">{{ name }}</a>{% endblocktrans %}</li>
    </ol>
  {% endblock %}
  <h1>{% blocktrans with name=object.station.name %}Weather conditions at {{ name }}{% endblocktrans %}</h1>
  <div class="panel panel-default">
    <div class="panel-heading">{% trans "Latest measurements" %}</div>
    <div class="panel-body">
      {% include "synopticgroupstation-report.html" %}
    </div>
  </div>
  <div class="charts">
    <center>
      {% for synoptic_timeseries in object.synoptictimeseries_set.primary %}
        <h2>{{ synoptic_timeseries.get_title }}</h2>
        <img src="../../../chart/{{ synoptic_timeseries.id }}.png">
        <hr>
      {% endfor %}
    </center>
  </div>
{% endblock %}
