{% extends "synopticbase.html" %}
{% load i18n %}


{% block title %}
  {% blocktrans with name=object.name %}
    {{ name }} meteorological report
  {% endblocktrans %}
{% endblock %}


{% block content %}
  <h1>{% trans "Latest measurements" %}</h1>
  {% for object in synoptic_group_stations %}
    <div class="panel panel-default">
      <div class="panel-heading"><a href="station/{{ object.id }}/">{{ object.station.name }}</a></div>
      <div class="panel-body">
        {% include "synopticgroupstation-report.html" %}
      </div>
    </div>
  {% endfor %}
{% endblock %}
